@@ -1,4 +1,4 @@
-/* ID: lad.h, last updated 2023-12-26, F.Osorio */
+/* ID: lad.h, last updated 2025-06-18, F.Osorio */
 
 #ifndef L1PACK_LAD_H
 #define L1PACK_LAD_H
@@ -15,6 +15,11 @@ void IRLS_increment(double *, double *, int, int, double *, double *, double *,
 /* linear programming method to solve L1 regression problems */
 void F77_NAME(l1br)(double *, double *, int *, int *, int *, int *, double *, double *, double *, int *, double *, int *, int *, int *);
 
+/* routines for estimation in the multivariate Laplace distribution */
+double do_weight(double, double);
+void E_step(double *, int, int, double *, double *, double *, double *);
+double logLik_Laplace(double *, int, int, double *);
+
 /* standard Laplace random generation */
 void rmlaplace_std(double *, int, int);
 
